@@ -3,14 +3,17 @@
 
 #include "SessionController.h"
 
-#include <Cursor.h>
-#include <InputHandler.h>
-#include <KLocalizedString>
-#include <PortalSession.h>
 #include <QAction>
 #include <QCoreApplication>
 #include <QDBusInterface>
 #include <QMenu>
+
+#include <KLocalizedString>
+
+#include <Clipboard.h>
+#include <Cursor.h>
+#include <InputHandler.h>
+#include <PortalSession.h>
 #include <RdpConnection.h>
 #include <Server.h>
 
@@ -20,6 +23,8 @@
 
 #include "VideoStream.h"
 
+using namespace Qt::StringLiterals;
+
 class SessionWrapper : public QObject
 {
     Q_OBJECT
@@ -33,9 +38,15 @@ public:
         connect(session.get(), &KRdp::AbstractSession::frameReceived, connection->videoStream(), &KRdp::VideoStream::queueFrame);
         connect(session.get(), &KRdp::AbstractSession::cursorUpdate, this, &SessionWrapper::onCursorUpdate);
         connect(session.get(), &KRdp::AbstractSession::error, this, &SessionWrapper::sessionError);
+        connect(session.get(), &KRdp::AbstractSession::clipboardDataChanged, connection->clipboard(), &KRdp::Clipboard::setServerData);
+
         connect(connection->videoStream(), &KRdp::VideoStream::enabledChanged, this, &SessionWrapper::onVideoStreamEnabledChanged);
         connect(connection->videoStream(), &KRdp::VideoStream::requestedFrameRateChanged, this, &SessionWrapper::onRequestedFrameRateChanged);
         connect(connection->inputHandler(), &KRdp::InputHandler::inputEvent, session.get(), &KRdp::AbstractSession::sendEvent);
+        connect(connection->clipboard(), &KRdp::Clipboard::clientDataChanged, session.get(), [clipboard = connection->clipboard(), this]() {
+            session->setClipboardData(clipboard->getClipboard());
+        });
+
         connect(connection, &QObject::destroyed, this, &SessionWrapper::onConnectionDestroyed);
     }
 
@@ -84,12 +95,12 @@ SessionController::SessionController(KRdp::Server *server, SessionType sessionTy
 {
     connect(m_server, &KRdp::Server::newConnectionCreated, this, &SessionController::onNewConnection);
     // Status notification item
-    m_sni = new KStatusNotifierItem(u"krdpserver"_qs, this);
-    auto menu = new QMenu(u"quitMenu"_qs);
+    m_sni = new KStatusNotifierItem(u"krdpserver"_s, this);
+    auto menu = new QMenu(u"quitMenu"_s);
     // Disable default quit button since it has confirmation dialog
     m_sni->setStandardActionsEnabled(false);
     m_sni->setTitle(i18n("RDP Server"));
-    m_sni->setIconByName(u"preferences-system-network-remote"_qs);
+    m_sni->setIconByName(u"preferences-system-network-remote"_s);
     m_sni->setStatus(KStatusNotifierItem::Passive);
     auto quitAction = new QAction(i18n("Quit"), menu);
     quitAction->setIcon(QIcon::fromTheme(QStringLiteral("application-exit")));
@@ -140,7 +151,6 @@ void SessionController::onNewConnection(KRdp::RdpConnection *newConnection)
         newConnection->close(KRdp::RdpConnection::CloseReason::None);
     });
 
-    wrapper->session->start();
     m_wrappers.push_back(std::move(wrapper));
 }
 
@@ -148,11 +158,11 @@ void SessionController::stopFromSNI()
 {
     // Uses dbus to stop the server service, like in the KCM
     // This kills all krdpserver instances, like a "panic button"
-    QDBusInterface unit(u"org.freedesktop.systemd1"_qs,
-                        u"/org/freedesktop/systemd1/unit/plasma_2dkrdp_5fserver_2eservice"_qs,
-                        u"org.freedesktop.systemd1.Unit"_qs);
+    QDBusInterface unit(u"org.freedesktop.systemd1"_s,
+                        u"/org/freedesktop/systemd1/unit/app_2dorg_2ekde_2ekrdpserver_2eservice"_s,
+                        u"org.freedesktop.systemd1.Unit"_s);
 
-    unit.asyncCall(u"Stop"_qs);
+    unit.asyncCall(u"Stop"_s);
     QCoreApplication::quit();
 }
 
